@@ -584,7 +584,7 @@ class ER:
                 # node exists, check equality and compare
                 if debugging: 
                     print(f"   ✓        exists")
-                    print(["test", n1, n1["nodeType"]])
+                    #print(["test", n1, n1["nodeType"]])
                     
                 
                 n2 = otherGraph.get_obj(n1["label"], n1["nodeType"])
@@ -709,10 +709,9 @@ class ER:
     def has_rel_adv(self, thisNode):
         propertyKeys = ['relationFrom', 'relationTo', 'fromEdgeLabel', 'toEdgeLabel', 'isWeak']
         x = self.get_obj("", NodeType.RELATION)
-        if self.debug: 
-            print(["testing with ", thisNode])
+        #if self.debug: print(["testing with ", thisNode])
         for otherNode in self.get_obj("", NodeType.RELATION):
-            if self.debug: print(["testing for ", otherNode])
+            #if self.debug: print(["testing for ", otherNode])
             for k in propertyKeys:
                 if self.__compare_properties(thisNode, otherNode, k, self.debug):
                     return True
@@ -745,14 +744,14 @@ class ER:
             potentialNode = obj[1]
             potentialNodeType = potentialNode.get("nodeType", NodeType.NOT_SPECIFIED)
             if ( node_type == NodeType.NOT_SPECIFIED or potentialNodeType == str(node_type) ):
-                if self.debug: print([f"label={label}  | nodeType={potentialNodeType}", "considering", potentialNode])
+                #if self.debug: print([f"label={label}  | nodeType={potentialNodeType}", "considering", potentialNode])
                 obj_label = potentialNode.get("label", "")
                 if label == "": 
-                    if self.debug: print([f"label={label}", "found", potentialNode])
+                    #if self.debug: print([f"label={label}", "found", potentialNode])
                     obj_list.append(potentialNode) # get all nodes of this type
                     continue
                 if label.endswith("."):
-                    print("wildcard" + label)
+                    if self.debug: print("wildcard " + label + ".*")
                     if obj_label.startswith(label):
                         obj_list.append(potentialNode)
                     continue
@@ -765,7 +764,7 @@ class ER:
                     left, bracket, rest = obj_label.partition("-->")
                     block, bracket, right = rest.partition("<--")
                     new_obj_label = left + right
-                    if self.debug: print(["checking", new_label, new_obj_label])
+                    #if self.debug: print(["checking", new_label, new_obj_label])
                     if new_label == new_obj_label:
                         return potentialNode
 
